import * as React from "react";
import { type Editor } from "@tiptap/react";
import type { ButtonProps } from "@/components/tiptap-ui-primitive/button";
export type NodeType = "codeBlock" | "blockquote";
export interface NodeButtonProps extends Omit<ButtonProps, "type"> {
    /**
     * The TipTap editor instance.
     */
    editor?: Editor | null;
    /**
     * The type of node to toggle.
     */
    type: NodeType;
    /**
     * Optional text to display alongside the icon.
     */
    text?: string;
    /**
     * Whether the button should hide when the node is not available.
     * @default false
     */
    hideWhenUnavailable?: boolean;
}
export declare const nodeIcons: {
    codeBlock: React.MemoExoticComponent<({ className, ...props }: React.SVGProps<SVGSVGElement>) => import("react/jsx-runtime").JSX.Element>;
    blockquote: React.MemoExoticComponent<({ className, ...props }: React.SVGProps<SVGSVGElement>) => import("react/jsx-runtime").JSX.Element>;
};
export declare const nodeShortcutKeys: Partial<Record<NodeType, string>>;
export declare const nodeLabels: Record<NodeType, string>;
export declare function canToggleNode(editor: Editor | null, type: NodeType): boolean;
export declare function isNodeActive(editor: Editor | null, type: NodeType): boolean;
export declare function toggleNode(editor: Editor | null, type: NodeType): boolean;
export declare function isNodeButtonDisabled(editor: Editor | null, canToggle: boolean, userDisabled?: boolean): boolean;
export declare function shouldShowNodeButton(params: {
    editor: Editor | null;
    type: NodeType;
    hideWhenUnavailable: boolean;
    nodeInSchema: boolean;
    canToggle: boolean;
}): boolean;
export declare function formatNodeName(type: NodeType): string;
export declare function useNodeState(editor: Editor | null, type: NodeType, disabled?: boolean, hideWhenUnavailable?: boolean): {
    nodeInSchema: boolean;
    canToggle: boolean;
    isDisabled: boolean;
    isActive: boolean;
    shouldShow: boolean;
    handleToggle: () => boolean;
    Icon: React.MemoExoticComponent<({ className, ...props }: React.SVGProps<SVGSVGElement>) => import("react/jsx-runtime").JSX.Element> | React.MemoExoticComponent<({ className, ...props }: React.SVGProps<SVGSVGElement>) => import("react/jsx-runtime").JSX.Element>;
    shortcutKey: string | undefined;
    label: string;
};
export declare const NodeButton: React.ForwardRefExoticComponent<NodeButtonProps & React.RefAttributes<HTMLButtonElement>>;
export default NodeButton;
