import { Node } from '@tiptap/core';
export type UploadFunction = (file: File, onProgress?: (event: {
    progress: number;
}) => void, abortSignal?: AbortSignal) => Promise<string>;
export interface ImageUploadOptions {
    /**
     * Acceptable file types for upload.
     * @default 'image/*'
     */
    accept?: string;
    /**
     * Maximum number of files that can be uploaded.
     * @default 1
     */
    limit?: number;
    /**
     * Maximum file size in bytes (0 for unlimited).
     * @default 0
     */
    maxSize?: number;
    /**
     * Function to handle the upload process.
     * Required parameter that must be provided when using the extension.
     */
    upload: UploadFunction;
    /**
     * Callback for upload errors.
     */
    onError?: (error: Error) => void;
    /**
     * Callback for successful uploads.
     */
    onSuccess?: (url: string) => void;
}
declare module '@tiptap/core' {
    interface Commands<ReturnType> {
        imageUpload: {
            /**
             * Add an image upload component
             */
            setImageUploadNode: (options?: Partial<ImageUploadOptions>) => ReturnType;
        };
    }
}
/**
 * A Tiptap node extension that creates an image upload component.
 * Allows for customizable image upload functionality
 */
export declare const ImageUploadExtension: Node<ImageUploadOptions, any>;
